psipy
=====

Tools for reading, processing, and visualising MHD models run by Predictive Science
Inc.

|docs| |build-status| |coverage|

.. |build-status| image:: https://github.com/predsci/PsiPy/workflows/Automated%20tests/badge.svg
    :alt: build status

.. |docs| image:: https://readthedocs.org/projects/psipy/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://psipy.readthedocs.io/en/latest/

.. |coverage| image:: https://codecov.io/gh/predsci/PsiPy/branch/main/graph/badge.svg?token=X76FIVNXP6
    :alt: Test coverage
    :scale: 100%
    :target: https://codecov.io/gh/predsci/PsiPy
